==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZadluzeniePozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.AktualnoscZadluzenia;
import pl.topteam.dps.enums.RodzajZadluzenia;
import pl.topteam.dps.enums.StatusPozycjiZadluzenia;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZadluzeniePozycja extends GenericDPSObject {
    /**
     * ZADLUZENIE_POZYCJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * ZADLUZENIE_POZYCJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzenieId;

    /**
     * ZADLUZENIE_POZYCJA.AKTUALNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private AktualnoscZadluzenia aktualnosc;

    /**
     * ZADLUZENIE_POZYCJA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * ZADLUZENIE_POZYCJA.RODZAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZadluzenia rodzaj;

    /**
     * ZADLUZENIE_POZYCJA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusPozycjiZadluzenia status;

    /**
     * ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataAktualizacji;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE_POZYCJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZADLUZENIE_POZYCJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzenieId() {
        return zadluzenieId;
    }

    /**
     * ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     *
     * @param zadluzenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzenieId(Long zadluzenieId) {
        this.zadluzenieId = zadluzenieId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.AKTUALNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public AktualnoscZadluzenia getAktualnosc() {
        return aktualnosc;
    }

    /**
     * ZADLUZENIE_POZYCJA.AKTUALNOSC
     *
     * @param aktualnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAktualnosc(AktualnoscZadluzenia aktualnosc) {
        this.aktualnosc = aktualnosc;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZADLUZENIE_POZYCJA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.RODZAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZadluzenia getRodzaj() {
        return rodzaj;
    }

    /**
     * ZADLUZENIE_POZYCJA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzaj(RodzajZadluzenia rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusPozycjiZadluzenia getStatus() {
        return status;
    }

    /**
     * ZADLUZENIE_POZYCJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusPozycjiZadluzenia status) {
        this.status = status;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataAktualizacji() {
        return dataAktualizacji;
    }

    /**
     * ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     *
     * @param dataAktualizacji
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataAktualizacji(Date dataAktualizacji) {
        this.dataAktualizacji = dataAktualizacji;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZadluzeniePozycja other = (ZadluzeniePozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZadluzenieId() == null ? other.getZadluzenieId() == null : this.getZadluzenieId().equals(other.getZadluzenieId()))
            && (this.getAktualnosc() == null ? other.getAktualnosc() == null : this.getAktualnosc().equals(other.getAktualnosc()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getDataAktualizacji() == null ? other.getDataAktualizacji() == null : this.getDataAktualizacji().equals(other.getDataAktualizacji()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZadluzenieId() == null) ? 0 : getZadluzenieId().hashCode());
        result = prime * result + ((getAktualnosc() == null) ? 0 : getAktualnosc().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getDataAktualizacji() == null) ? 0 : getDataAktualizacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zadluzenieId=").append(zadluzenieId);
        sb.append(", aktualnosc=").append(aktualnosc);
        sb.append(", kwota=").append(kwota);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", status=").append(status);
        sb.append(", dataAktualizacji=").append(dataAktualizacji);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZadluzeniePozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.AktualnoscZadluzenia;
import pl.topteam.dps.enums.RodzajZadluzenia;
import pl.topteam.dps.enums.StatusPozycjiZadluzenia;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZadluzeniePozycja extends GenericDPSObject {
    /**
     * ZADLUZENIE_POZYCJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * ZADLUZENIE_POZYCJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzenieId;

    /**
     * ZADLUZENIE_POZYCJA.AKTUALNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private AktualnoscZadluzenia aktualnosc;

    /**
     * ZADLUZENIE_POZYCJA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * ZADLUZENIE_POZYCJA.RODZAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZadluzenia rodzaj;

    /**
     * ZADLUZENIE_POZYCJA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusPozycjiZadluzenia status;

    /**
     * ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataAktualizacji;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE_POZYCJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ZADLUZENIE_POZYCJA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZADLUZENIE_POZYCJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzenieId() {
        return zadluzenieId;
    }

    /**
     * ZADLUZENIE_POZYCJA.ZADLUZENIE_ID
     *
     * @param zadluzenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzenieId(Long zadluzenieId) {
        this.zadluzenieId = zadluzenieId;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.AKTUALNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public AktualnoscZadluzenia getAktualnosc() {
        return aktualnosc;
    }

    /**
     * ZADLUZENIE_POZYCJA.AKTUALNOSC
     *
     * @param aktualnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAktualnosc(AktualnoscZadluzenia aktualnosc) {
        this.aktualnosc = aktualnosc;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZADLUZENIE_POZYCJA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.RODZAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZadluzenia getRodzaj() {
        return rodzaj;
    }

    /**
     * ZADLUZENIE_POZYCJA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzaj(RodzajZadluzenia rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusPozycjiZadluzenia getStatus() {
        return status;
    }

    /**
     * ZADLUZENIE_POZYCJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusPozycjiZadluzenia status) {
        this.status = status;
    }

    /**
     * @return ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataAktualizacji() {
        return dataAktualizacji;
    }

    /**
     * ZADLUZENIE_POZYCJA.DATA_AKTUALIZACJI
     *
     * @param dataAktualizacji
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataAktualizacji(Date dataAktualizacji) {
        this.dataAktualizacji = dataAktualizacji;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZadluzeniePozycja other = (ZadluzeniePozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZadluzenieId() == null ? other.getZadluzenieId() == null : this.getZadluzenieId().equals(other.getZadluzenieId()))
            && (this.getAktualnosc() == null ? other.getAktualnosc() == null : this.getAktualnosc().equals(other.getAktualnosc()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getDataAktualizacji() == null ? other.getDataAktualizacji() == null : this.getDataAktualizacji().equals(other.getDataAktualizacji()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZadluzenieId() == null) ? 0 : getZadluzenieId().hashCode());
        result = prime * result + ((getAktualnosc() == null) ? 0 : getAktualnosc().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getDataAktualizacji() == null) ? 0 : getDataAktualizacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zadluzenieId=").append(zadluzenieId);
        sb.append(", aktualnosc=").append(aktualnosc);
        sb.append(", kwota=").append(kwota);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", status=").append(status);
        sb.append(", dataAktualizacji=").append(dataAktualizacji);
        sb.append("]");
        return sb.toString();
    }
}
